#version 100

uniform lowp sampler2D diffuse_texture;
varying highp vec2 frag_tex_coord;

#if defined(VARYING_COLOR)
varying lowp vec4 frag_color;
#else
uniform lowp vec4 global_color;
#endif

#if defined(SPLIT_ALPHA)
uniform lowp sampler2D diffuse_alpha_texture;
varying mediump vec2 frag_alpha_tex_coord;
#endif

#if defined(FOG)
varying mediump float fog_factor;
uniform lowp vec4 fog_color;
#endif

void main(void)
{
	lowp vec4 tex_color = texture2D(diffuse_texture, frag_tex_coord);

#if defined(SPLIT_ALPHA)
	tex_color.a = texture2D(diffuse_alpha_texture, frag_alpha_tex_coord).a;
#endif

	lowp vec4 out_color  = tex_color *
#if defined(VARYING_COLOR)
						   frag_color;
#else
						   global_color;
#endif

#if defined(FOG)
	gl_FragColor = mix(fog_color, out_color, vec4(fog_factor, fog_factor, fog_factor, 1.0));
#else
	gl_FragColor = out_color;
#endif
}

